==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/tsf/v20180326/models/DeleteImageTagsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tsf.v20180326.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteImageTagsRequest  extends AbstractModel{

    /**
    * 镜像版本数组
    */
    @SerializedName("ImageTags")
    @Expose
    private DeleteImageTag [] ImageTags;

    /**
     * 获取镜像版本数组
     * @return ImageTags 镜像版本数组
     */
    public DeleteImageTag [] getImageTags() {
        return this.ImageTags;
    }

    /**
     * 设置镜像版本数组
     * @param ImageTags 镜像版本数组
     */
    public void setImageTags(DeleteImageTag [] ImageTags) {
        this.ImageTags = ImageTags;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ImageTags.", this.ImageTags);

    }
}

==> tencentcloud-sdk-java-3.1.135-sources.jar: com/tencentcloudapi/tsf/v20180326/models/DeleteImageTagsRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tsf.v20180326.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteImageTagsRequest extends AbstractModel{

    /**
    * 镜像版本数组
    */
    @SerializedName("ImageTags")
    @Expose
    private DeleteImageTag [] ImageTags;

    /**
     * Get 镜像版本数组 
     * @return ImageTags 镜像版本数组
     */
    public DeleteImageTag [] getImageTags() {
        return this.ImageTags;
    }

    /**
     * Set 镜像版本数组
     * @param ImageTags 镜像版本数组
     */
    public void setImageTags(DeleteImageTag [] ImageTags) {
        this.ImageTags = ImageTags;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "ImageTags.", this.ImageTags);

    }
}
